@@ -5,7 +5,7 @@
 distname = 'cubicweb-saem-ref'
 modname = 'cubicweb_saem_ref'
 
-numversion = (0, 17, 2)
+numversion = (0, 21, 1)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -15,17 +15,18 @@ description = "Référenciel de Système d'Archivage Électronique Mutualisé"
 web = 'http://www.cubicweb.org/project/%s' % distname
 
 __depends__ = {
-    'cubicweb[pyramid]': '>= 3.25.0, < 3.26.0',
+    'cubicweb[pyramid]': '>= 3.26.1',
     'cubicweb-squareui': None,
-    'cubicweb-eac': '>= 0.6.0, < 0.7.0',
-    'cubicweb-seda': '>= 0.13.0, < 0.14.0',
+    'cubicweb-eac': '>= 0.7.0, < 0.8.0',
+    'cubicweb-seda': '>= 0.14.0, < 0.15.0',
     'cubicweb-compound': '>= 0.7.0, < 0.8.0',
     'cubicweb-prov': '>= 0.4.0, < 0.5.0',
-    'cubicweb-oaipmh': '>= 0.4.2, < 0.5.0',
+    'cubicweb-oaipmh': '>= 0.5.0, < 0.6.0',
     'cubicweb-relationwidget': '>= 0.4.0, < 0.5.0',
-    'cubicweb-skos': '>= 1.2.1, < 1.3.0',
+    'cubicweb-skos': '>= 1.5.0',
     'cubicweb-vtimeline': None,
     'cubicweb-signedrequest': None,
+    'isodate': None,
     'python-dateutil': None,
     'pytz': None,
     'psycopg2': None,
