@@ -208,6 +208,7 @@ class AssignARKHook(hook.Hook):
     __select__ = hook.Hook.__select__ & relation_possible('ark')
     events = ('before_add_entity',)
     order = metadata.InitMetaAttrsHook.order - 1
+    category = 'metadata'
 
     def __call__(self):
         if not self.entity.cw_edited.get('ark'):
@@ -481,6 +482,53 @@ class UnlinkDeprecatedProfileFromOrganizationUnit(hook.Hook):
                          {'x': self.entity.for_entity.eid})
 
 
+class CheckSchemeRelationTypeBeforeDeprecation(hook.Hook):
+    """Prevent ConceptScheme deprecation if it used as a "scheme_relation_type".
+    """
+    __select__ = (
+        hook.Hook.__select__
+        & on_fire_transition('ConceptScheme', 'deprecate')
+    )
+    __regid__ = 'saem.check-scheme-relation-type-before-deprecation'
+    events = ('after_add_entity',)
+
+    def __call__(self):
+        scheme_to_seda_rtypes = [
+            ('scheme_relation_type', 'subject'),
+            ('scheme_entity_type', 'subject'),
+            ('seda_keyword_reference_to_scheme', 'object'),
+            ('seda_message_digest_algorithm_code_list_version_to', 'object'),
+            ('seda_mime_type_code_list_version_to', 'object'),
+            ('seda_encoding_code_list_version_to', 'object'),
+            ('seda_file_format_code_list_version_to', 'object'),
+            ('seda_compression_algorithm_code_list_version_to', 'object'),
+            ('seda_data_object_version_code_list_version_to', 'object'),
+            ('seda_storage_rule_code_list_version_to', 'object'),
+            ('seda_appraisal_rule_code_list_version_to', 'object'),
+            ('seda_access_rule_code_list_version_to', 'object'),
+            ('seda_dissemination_rule_code_list_version_to', 'object'),
+            ('seda_reuse_rule_code_list_version_to', 'object'),
+            ('seda_classification_rule_code_list_version_to', 'object'),
+            ('seda_acquisition_information_code_list_version_to', 'object'),
+            ('seda_relationship_code_list_version_to', 'object'),
+        ]
+        qs = ' OR '.join(
+            'EXISTS({subject} {rtype} {object})'.format(
+                subject='X' if role == 'subject' else 'Y%d' % idx,
+                object='X' if role == 'object' else 'Y%d' % idx,
+                rtype=rtype,
+            )
+            for idx, (rtype, role) in enumerate(scheme_to_seda_rtypes)
+        )
+        rset = self._cw.execute('Any X WHERE X eid %(x)s, ' + qs,
+                                {'x': self.entity.for_entity.eid})
+        if rset:
+            raise ValidationError(
+                self.entity.for_entity.eid,
+                {None: _('this concept scheme is used in at least one SEDA constraint')},
+            )
+
+
 # Relations deposit agent - archival agent  ####################################
 
 class DontDeleteUnitIfArchival(hook.Hook):
@@ -518,6 +566,19 @@ class AuthorityRecordUsedBySetDefault(hook.Hook):
             {'u': self.eidto, 'ar': self.eidfrom})
 
 
+# Define index for sorted composite relation ###################################
+
+class InitializeIndexOnCreation(hook.Hook):
+    """An entity which is part of a collection is created"""
+    __regid__ = 'saem.sortable.created'
+    __select__ = hook.Hook.__select__ & adaptable('ISortable')
+    events = ('before_add_entity',)
+
+    def __call__(self):
+        # Ensure we use an index greater than every other
+        self.entity.cw_edited['index'] = self.entity.eid
+
+
 def registration_callback(vreg):
     vreg.register_all(globals().values(), __name__)
 
