@@ -17,7 +17,10 @@
 """cubicweb-saem-ref schema"""
 
 from yams.buildobjs import EntityType, RelationDefinition, String, Int, ComputedRelation
-from yams.constraints import UniqueConstraint
+from yams.constraints import (
+    IntervalBoundConstraint,
+    UniqueConstraint,
+)
 
 from cubicweb import _
 from cubicweb.schema import (RO_ATTR_PERMS, ERQLExpression, RRQLExpression,
@@ -28,24 +31,28 @@ from cubicweb.schemas.base import ExternalUri, EmailAddress
 from cubicweb_skos import schema as skos
 from cubicweb_prov import schema as prov
 from cubicweb_eac import schema as eac
-from cubicweb_seda.schema import simplified_profile
-from cubicweb_seda.schema.seda2 import SEDAArchiveTransfer
+from cubicweb_seda.schema import (
+    seda2,
+    simplified_profile,
+)
 from cubicweb_compound import utils
 
 
-def publication_permissions(cls, groups=('managers', 'users')):
+def publication_permissions(cls, groups=('managers', 'users'),
+                            states=('draft', )):
     """Set __permissions__ of `cls` entity type class preventing modification
-    when not in state "draft".
+    when not in specified states.
     """
     groups = ', '.join('"{}"'.format(group) for group in groups)
+    states = ', '.join('"{}"'.format(state) for state in states)
     cls.__permissions__ = cls.__permissions__.copy()
     cls.__permissions__['update'] = (
         ERQLExpression('U in_group G, G name IN ({}), '
-                       'X in_state ST, ST name "draft"'.format(groups)),
+                       'X in_state ST, ST name IN ({})'.format(groups, states)),
     )
     cls.__permissions__['delete'] = (
         ERQLExpression('U in_group G, G name IN ({}), '
-                       'X in_state ST, ST name "draft"'.format(groups)),
+                       'X in_state ST, ST name IN ({})'.format(groups, states)),
     )
     return cls
 
@@ -130,10 +137,21 @@ for etype_def in (eac.ChronologicalRelation,
     }
 
 
+class index(RelationDefinition):
+    subject = ('AgentFunction', 'Mandate')
+    object = 'Int'
+    description = _('index of entity as an item of the collection of similar '
+                    'entities related to a given authority record')
+    cardinality = '?1'
+    constraints = [IntervalBoundConstraint(0)]
+
+
 # SKOS #########################################################################
 
 make_workflowable(skos.ConceptScheme)
-publication_permissions(skos.ConceptScheme, groups=('managers',))
+publication_permissions(skos.ConceptScheme,
+                        groups=('managers',),
+                        states=('draft', 'deprecated'))
 skos.ConceptScheme.__permissions__['add'] = ('managers',)
 
 skos.in_scheme.cardinality = '1*'
@@ -394,6 +412,7 @@ class ark(RelationDefinition):
         'Organization',
         'OrganizationUnit',
         'SEDAArchiveTransfer',
+        'SEDAArchiveUnit',
     )
     object = 'String'
     description = _('ARK Identifier - will be generated if not specified')
@@ -419,6 +438,7 @@ class _ark_naa(RelationDefinition):
     name = 'ark_naa'
     object = 'ArkNameAssigningAuthority'
     inlined = True
+    description = _("ARK identifier Name Assigning Authority (NAA)")
 
 
 class organization_ark_naa(_ark_naa):
@@ -441,7 +461,16 @@ class mandatory_ark_naa(_ark_naa):
     }
     subject = ('AuthorityRecord', 'SEDAArchiveTransfer')
     cardinality = '1*'
-    description = _("ARK identifier Name Assigning Authority (NAA)")
+
+
+class archive_unit_ark_naa(_ark_naa):
+    __permissions__ = {
+        'read': ('managers', 'users', 'guests'),
+        'add': ('managers', 'users',),
+        'delete': (),
+    }
+    subject = 'SEDAArchiveUnit'
+    cardinality = '?*'
 
 
 class optional_ark_naa(_ark_naa):
@@ -458,13 +487,18 @@ class optional_ark_naa(_ark_naa):
 
 # SEDA #######################################################################
 
-make_workflowable(SEDAArchiveTransfer)
-publication_permissions(SEDAArchiveTransfer)
+make_workflowable(seda2.SEDAArchiveTransfer)
+publication_permissions(seda2.SEDAArchiveTransfer)
 
 
 simplified_profile.default = True
 
 
+seda2.originating_agency_originating_agency_to.constraints.append(
+    RQLConstraint('O in_state ST, ST name "published"')
+)
+
+
 @authority_permissions_rdef
 class use_profile(RelationDefinition):
     subject = 'OrganizationUnit'
