@@ -17,6 +17,8 @@
 
 from functools import wraps
 
+from six import text_type
+
 from logilab.common.decorators import monkeypatch
 from logilab.mtconverter import xml_escape
 from logilab.common.registry import yes
@@ -26,10 +28,19 @@ from cubicweb import NoSelectableObject, neg_role, tags
 from cubicweb.utils import json_dumps, js_href
 from cubicweb.uilib import domid, js
 from cubicweb.view import EntityView
+from cubicweb.web.views import ajaxcontroller
 from cubicweb.predicates import (has_permission, is_instance, multi_lines_rset, match_kwargs,
                                  partial_has_related_entities)
 from cubicweb.web import component, formwidgets as fw
-from cubicweb.web.views import basecomponents, uicfg, urlrewrite, tabs, primary
+from cubicweb.web.views import (
+    basecomponents,
+    baseviews,
+    primary,
+    tabs,
+    uicfg,
+    urlpublishing,
+    urlrewrite,
+)
 
 from cubes.squareui.views.basetemplates import basetemplates
 from cubicweb_seda.views import dropdown_button, has_rel_perm, widgets as sedawidgets
@@ -292,6 +303,24 @@ class SAEMHTMLPageFooter(basetemplates.HTMLPageFooter):
                logo_mairie=self._cw.data_url('mairie_bx.jpg')))
 
 
+class SortableListView(baseviews.ListView):
+    __regid__ = 'sortable-list'
+    __select__ = baseviews.ListView.__select__ & match_kwargs('listid')
+
+    def call(self, **kwargs):
+        self._cw.add_js('cubes.saem_ref.js')
+        listid = kwargs['listid']
+        self._cw.add_onload(
+            js.saem.makeSortable(listid, kwargs['rtype'])
+        )
+        super(SortableListView, self).call(**kwargs)
+
+    def cell_call(self, row, col=0, vid=None, klass=None, **kwargs):
+        self.w(u'<li data-eid={} >'.format(self.cw_rset[row][0]))
+        self.wview(self.item_vid, self.cw_rset, row=row, col=col, vid=vid, **kwargs)
+        self.w(u'</li>')
+
+
 class RelatedEntitiesListView(EntityView):
     """Abstract entity view for displaying an related entities in a list.
 
@@ -304,9 +333,18 @@ class RelatedEntitiesListView(EntityView):
     rtype = None
     role = 'object'
     subvid = 'saem.listitem'
+    listvid = 'list'
     target_etype = None
     subvid_kwargs = None
 
+    def related_rset(self, entity):
+        if self.target_etype is not None:
+            targettypes = (self.target_etype, )
+        else:
+            targettypes = None
+        return entity.related(self.rtype, role=self.role,
+                              targettypes=targettypes)
+
     @property
     def title(self):
         return self.rtype + '_object' if self.role == 'object' else self.rtype
@@ -314,14 +352,9 @@ class RelatedEntitiesListView(EntityView):
     def entity_call(self, entity, **kwargs):
         kwargs.update(self.subvid_kwargs or {})
         kwargs['__redirectpath'] = entity.rest_path()
-        if self.target_etype is not None:
-            targettypes = (self.target_etype, )
-        else:
-            targettypes = None
-        rset = entity.related(self.rtype, role=self.role,
-                              targettypes=targettypes)
         if self.title:
             self.w(tags.h2(self._cw._(self.title)))
+        rset = self.related_rset(entity)
         if len(rset) == 1:
             self._cw.view(self.subvid, rset=rset, w=self.w, **kwargs)
         else:
@@ -329,7 +362,10 @@ class RelatedEntitiesListView(EntityView):
             self.divid = u'{}{}'.format(domid(self.__regid__), entity.eid)
             self.w(u'<div id="{}">'.format(self.divid))
             self.do_paginate(rset=rset)
-            self._cw.view('list', rset=rset, w=self.w, subvid=self.subvid, **kwargs)
+            listid = self.divid + "_list"
+            kwargs['rtype'] = self.rtype
+            self._cw.view(self.listvid, rset=rset, w=self.w,
+                          subvid=self.subvid, listid=listid, **kwargs)
             self.w(u'</div>')
 
     def page_navigation_url(self, navcomp, _path, params):
@@ -429,11 +465,65 @@ class URLAttributeView(primary.URLAttributeView):
             self.w(u'<a href="%s">%s</a>' % (url, url))
 
 
+class SAEMNoResultView(baseviews.NoResultView):
+    """Enhanced "noresult" view with a nicer message and an invite to create
+    an entity when permission is granted.
+    """
+
+    def call(self, **kwargs):
+        vreg = self._cw.vreg
+        try:
+            etype = self.cw_rset.description[0][0]
+        except IndexError:
+            # rset probably comes from a user RQL query, fall back to default
+            # behavior.
+            return super(SAEMNoResultView, self).call(**kwargs)
+        if etype not in vreg['etypes']:
+            # Or the first select query variable is not the entity type.
+            return super(SAEMNoResultView, self).call(**kwargs)
+        msg = self._cw._('No entity of type "{etype}" yet.').format(
+            etype=self._cw.__(etype)
+        )
+        self.w(u'<div class="searchMessage">{}'.format(
+            xml_escape(msg)))
+        if vreg.schema[etype].has_perm(self._cw, 'add'):
+            self.w(u' <a href="{url}">{invite}</a>'.format(
+                url=vreg['etypes'].etype_class(etype).cw_create_url(self._cw),
+                invite=xml_escape(self._cw._('Create one?')),
+            ))
+        self.w(u'</div>')
+
+
+class RestPathEvaluator(urlpublishing.RestPathEvaluator):
+
+    def set_vid_for_rset(self, req, cls, rset):
+        if rset.rowcount == 0:
+            req.form['vid'] = 'noresult'
+            return
+        return super(RestPathEvaluator, self).set_vid_for_rset(req, cls, rset)
+
+
+@ajaxcontroller.ajaxfunc(output_type='json')
+def sort_relation_targets(self, rtype, eids):
+    first_item = self._cw.entity_from_eid(eids[0]).cw_adapt_to('ISortable')
+    collection = first_item.collection
+    for item in collection:
+        index = next(idx for idx, v in enumerate(eids) if v == text_type(item.eid))
+        item.cw_set(index=index)
+
+
 def registration_callback(vreg):
     from cubicweb.web.views import actions, cwuser, tableview, undohistory
-    vreg.register_all(globals().values(), __name__, (URLAttributeView, SAEMHTMLPageFooter,))
+    vreg.register_all(globals().values(), __name__, (
+        RestPathEvaluator,
+        SAEMHTMLPageFooter,
+        SAEMNoResultView,
+        URLAttributeView,
+    ))
+    vreg.register_and_replace(RestPathEvaluator, urlpublishing.RestPathEvaluator)
     vreg.register_and_replace(URLAttributeView, primary.URLAttributeView)
     vreg.register_and_replace(SAEMHTMLPageFooter, basetemplates.HTMLPageFooter)
+    vreg.register_and_replace(SAEMNoResultView, baseviews.NoResultView)
     vreg.unregister(tableview.TableView)
     vreg.unregister(undohistory.UndoHistoryView)
     vreg.unregister(basecomponents.ApplicationName)
