@@ -60,6 +60,10 @@ for rtype in ('chronological_predecessor', 'chronological_successor',
 
 afs.tag_object_of(('*', 'use_authorityrecord', 'AuthorityRecord'), 'main', 'hidden')
 
+for etype in ('Mandate', 'AgentFunction'):
+    pvs.tag_attribute((etype, 'index'), 'hidden')
+    afs.tag_attribute((etype, 'index'), 'main', 'hidden')
+
 
 class EACImportComponent(ImportEntityComponent):
     """Component with a link to import an authority record from an EAC-CPF file."""
@@ -194,6 +198,15 @@ class CitationLinkView(EntityView):
             self.w(u'<i class="truncate">%s</i>' % title)
 
 
+# Use a list view to display name entries show "authorized" form first.
+pvdc.tag_object_of(('*', 'name_entry_for', 'AuthorityRecord'), {
+    'vid': 'list',
+    # we "abuse" filter option to actually sort the rset the way we want.
+    'filter': lambda rset: rset.sorted_rset(
+        lambda x: (x.form_variant != 'authorized', x.creation_date)),
+})
+
+
 class AuthorityRecordPrimaryTab(tabs.PrimaryTab):
     """Main tab for authority record, just with a different regid."""
     __regid__ = 'saem_authorityrecord_general_information_tab'
@@ -364,7 +377,22 @@ class AuthorityRecordPlaceAsConceptView(EntityView):
 pvs.tag_object_of(('*', 'function_agent', 'AuthorityRecord'), 'hidden')
 
 
-class AuthorityRecordFunctionView(RelatedEntitiesListView):
+class SortableListViewMixin(object):
+
+    @property
+    def listvid(self):
+        entity = self.cw_rset.one()
+        if entity.cw_has_perm('update'):
+            return 'sortable-list'
+        else:
+            return 'list'
+
+    def related_rset(self, entity):
+        rset = super(SortableListViewMixin, self).related_rset(entity)
+        return rset.sorted_rset(lambda entity: entity.index)
+
+
+class AuthorityRecordFunctionView(SortableListViewMixin, RelatedEntitiesListView):
     """View for AgentFunction, to be display in the context of an AuthorityRecord"""
     __regid__ = 'saem.authorityrecord.functions'
     rtype = 'function_agent'
@@ -377,7 +405,7 @@ class AuthorityRecordFunctionView(RelatedEntitiesListView):
 pvs.tag_object_of(('*', 'mandate_agent', 'AuthorityRecord'), 'hidden')
 
 
-class AuthorityRecordMandateView(RelatedEntitiesListView):
+class AuthorityRecordMandateView(SortableListViewMixin, RelatedEntitiesListView):
     """View for Mandate, to be displayed in the context of an AuthorityRecord"""
     __regid__ = 'saem.authorityrecord.mandate'
     rtype = 'mandate_agent'
