@@ -18,17 +18,14 @@
 import sys
 from io import BytesIO, StringIO
 
-from cubicweb.devtools import testlib
+from cubicweb.devtools import (
+    PostgresApptestConfiguration,
+    testlib,
+)
 from cubicweb.cwconfig import CubicWebConfiguration
-try:
-    from cubicweb.devtools import PostgresApptestConfiguration
-except ImportError as exc:
-    import pytest
-    pytestmark = pytest.mark.skipif(True, reason=str(exc))
-else:
-    from cubicweb_eac import ccplugin
 
-from cubes.skos import ccplugin as skos
+from cubicweb_eac import ccplugin
+from cubicweb_skos import ccplugin as skos
 
 import testutils
 
@@ -77,7 +74,7 @@ class ImportEacDataCommandTC(CCPluginTC):
         with self.admin_access.repo_cnx() as cnx:
             record = cnx.find('AuthorityRecord').one()
             self.assertEqual(record.dc_title(), u"Centre d'information et d'orientation (CIO)")
-            self.assertTrue(record.ark.startswith('0/r0'), record.ark)
+            self.assertTrue(testutils.match_ark(record.ark), record.ark)
 
     def test_bad_authority(self):
         code, output = self.run_import_eac('--authority', 'unexisting')
@@ -104,6 +101,8 @@ class ImportEacDataCommandTC(CCPluginTC):
 
 class ImportSkosDataCommandTC(CCPluginTC):
 
+    configcls = PostgresApptestConfiguration
+
     def run_import_skos(self, *args):
         cmd = [self.appid] + list(args)
         sys.stdout = output = StringIO()
@@ -119,16 +118,17 @@ class ImportSkosDataCommandTC(CCPluginTC):
 
     def test_lcsv(self):
         with self.admin_access.cnx() as cnx:
+            naa = testutils.naa(cnx)
             scheme = cnx.create_entity('ConceptScheme', title=u'lcsv',
-                                       ark=u'123/345')
-            naa_what = testutils.naa(cnx).what
+                                       ark_naa=naa)
             cnx.commit()
             scheme_uri = scheme.cwuri
+            assert scheme.ark_naa
+            assert scheme.ark
         code, output = self.run_import_skos(
             self.datapath('lcsv_example_shortened.csv'),
             '--format', 'lcsv',
-            '--scheme', scheme_uri,
-            '--naa-what', naa_what,
+            '--scheme', scheme.ark,
         )
         self.assertEqual(code, 0, output)
         with self.admin_access.cnx() as cnx:
@@ -136,13 +136,18 @@ class ImportSkosDataCommandTC(CCPluginTC):
             self.assertEqual(len(scheme.reverse_in_scheme), 3)
 
     def test_lcsv_missing_naa_what(self):
+        with self.admin_access.cnx() as cnx:
+            scheme = cnx.create_entity('ConceptScheme', title=u'lcsv',
+                                       ark=u'0/123', cwuri=u'123')
+            cnx.commit()
+            assert not scheme.ark_naa
         code, output = self.run_import_skos(
-            'whatever',
+            self.datapath('lcsv_example_shortened.csv'),
             '--format', 'lcsv',
-            '--scheme', 'whatever',
+            '--scheme', '0/123',
         )
-        self.assertEqual(code, 1)
-        self.assertIn('command failed: --naa-what option is required', output)
+        self.assertEqual(code, 1, output)
+        self.assertIn('command failed: specified concept scheme', output)
 
 
 if __name__ == '__main__':
