@@ -74,6 +74,8 @@ class ArkURLTC(testlib.CubicWebTC):
             'Organization': partial(testutils.authority_with_naa),
             'OrganizationUnit': partial(testutils.organization_unit, name=u'ou'),
             'SEDAArchiveTransfer': testutils.setup_profile,
+            'SEDAArchiveUnit': lambda cnx: testutils.create_archive_unit(
+                None, cnx=cnx, ark_naa=testutils.naa(cnx))[0],
         }
         baseurl = self.vreg.config['base-url']
         with self.admin_access.cnx() as cnx:
@@ -151,7 +153,7 @@ class AutomaticWebTest(testlib.AutomaticWebTest):
 
     def post_populate(self, cnx):
         unit, alt, alt_seq = testutils.create_archive_unit(
-            cnx.find('SEDAArchiveTransfer').one())
+            cnx.find('SEDAArchiveTransfer').one(), ark=u'0/dummy')
         testutils.create_data_object(alt_seq)
 
         cnx.execute('SET L kind "preferred" WHERE NOT EXISTS (L label_of X, L kind "preferred")')
