@@ -38,10 +38,20 @@ from cubicweb_saem_ref import ark
 # make some names them appear in this module namespace to ease test API
 assertValidationError = seda_testutils.assertValidationError
 assertUnauthorized = seda_testutils.assertUnauthorized
-create_archive_unit = seda_testutils.create_archive_unit
 create_data_object = seda_testutils.create_data_object
 
 
+def create_archive_unit(parent, *args, **kwargs):
+    """Create a SEDAArchiveTransfer with an "ark_naa" relation set."""
+    if 'ark_naa' not in kwargs:
+        cnx = kwargs.get('cnx', getattr(parent, '_cw', None))
+        assert cnx is not None
+        authority = authority_with_naa(cnx)
+        authority.cw_clear_all_caches()
+        kwargs['ark_naa'] = authority.ark_naa
+    return seda_testutils.create_archive_unit(parent, *args, **kwargs)
+
+
 def _authority(func):
     """Decorator binding an Organization with an NAA configured in
     kwargs['authority'].
