@@ -15,6 +15,7 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 """cubicweb-saem_ref unit tests for entities.container"""
 
+from cubicweb.devtools import PostgresApptestConfiguration
 from cubicweb.devtools.testlib import CubicWebTC
 
 from cubicweb_saem_ref.entities import container
@@ -22,6 +23,10 @@ from cubicweb_saem_ref.entities import container
 import testutils
 
 
+def setUpModule():
+    testutils.startpgcluster(__file__)
+
+
 def sort_container(container_def):
     for k, v in container_def:
         yield k, sorted(v)
@@ -29,6 +34,8 @@ def sort_container(container_def):
 
 class ContainerTC(CubicWebTC):
 
+    configcls = PostgresApptestConfiguration
+
     def test_authorityrecord_container(self):
         # line below should be copied from entities.container.registration_callback
         container_def = container.authority_record_container_def(self.schema)
@@ -76,6 +83,8 @@ class ContainerTC(CubicWebTC):
 
 class TreeTC(CubicWebTC):
 
+    configcls = PostgresApptestConfiguration
+
     def test_seda_profile_clone(self):
         """Functional test for SEDA profile cloning."""
         with self.admin_access.repo_cnx() as cnx:
