@@ -219,6 +219,13 @@ class SAEMRefHooksTC(CubicWebTC):
                               reverse_use_email=cnx.user.eid)
             cnx.commit()
 
+    def test_sortable_index_is_eid_on_creation(self):
+        with self.admin_access.cnx() as cnx:
+            arecord = testutils.authority_record(cnx, u'test')
+            mandate = cnx.create_entity('Mandate', term=u'casting', mandate_agent=arecord)
+            cnx.commit()
+            self.assertEqual(mandate.eid, mandate.index)
+
 
 class ARKGenerationHooksTC(CubicWebTC):
 
@@ -293,6 +300,19 @@ class ARKGenerationHooksTC(CubicWebTC):
             self._check_ark(profile)
             self.assertEqual(profile.cwuri, 'http://example.org/profile/125')
 
+    def test_ark_generation_seda_archiveunit(self):
+        with self.admin_access.repo_cnx() as cnx:
+            naa = testutils.naa(cnx)
+            unit, _, _ = testutils.create_archive_unit(None, cnx=cnx, ark_naa=naa)
+            self._check_ark_and_cwuri(unit)
+
+    def test_ark_generation_seda_archiveunit_in_archivetransfer(self):
+        with self.admin_access.repo_cnx() as cnx:
+            profile = testutils.setup_profile(cnx)
+            unit, _, _ = testutils.create_archive_unit(profile, cnx)
+            self._check_ark_and_cwuri(unit)
+            self.assertTrue(unit.ark.startswith('0/'), unit.ark)
+
     def test_ark_generation_concept(self):
         with self.admin_access.repo_cnx() as cnx:
             scheme = cnx.create_entity('ConceptScheme', ark_naa=testutils.naa(cnx))
@@ -649,5 +669,25 @@ class SEDAArchiveTransferHooksTC(CubicWebTC):
             self.assertFalse(organization_unit.use_profile)
 
 
+class ConceptSchemeWorkflowPermissionsTC(CubicWebTC):
+
+    configcls = PostgresApptestConfiguration
+
+    def test_cannot_deprecate_used_vocabulary(self):
+        with self.admin_access.cnx() as cnx:
+            scheme = testutils.scheme_for_type(cnx, u'seda_keyword_type_to', None,
+                                               u'type1')
+            cnx.commit()
+            scheme.cw_adapt_to('IWorkflowable').fire_transition('publish')
+            cnx.commit()
+            assert scheme.scheme_relation_type
+            with self.assertRaises(ValidationError) as cm:
+                scheme.cw_adapt_to('IWorkflowable').fire_transition('deprecate')
+            cnx.rollback()
+            self.assertIn(
+                'this concept scheme is used in at least one SEDA constraint',
+                str(cm.exception))
+
+
 if __name__ == '__main__':
     unittest.main()
