@@ -18,6 +18,7 @@
 import unittest
 from datetime import date
 
+from cubicweb.devtools import PostgresApptestConfiguration
 from cubicweb.devtools.testlib import CubicWebTC
 
 from cubicweb_compound.utils import optional_relations, graph_relations
@@ -26,6 +27,10 @@ from cubicweb_saem_ref import ConceptSchemeGraph
 import testutils
 
 
+def setUpModule():
+    testutils.startpgcluster(__file__)
+
+
 def create_published_records_panel(cnx):
     for name, kind in (
         (u"Mr Pink", u"person"),
@@ -39,6 +44,8 @@ def create_published_records_panel(cnx):
 
 
 class SchemaConstraintsTC(CubicWebTC):
+
+    configcls = PostgresApptestConfiguration
     assertValidationError = testutils.assertValidationError
 
     def test_published_constraint_on_contact_point(self):
@@ -227,6 +234,8 @@ class SchemaConstraintsTC(CubicWebTC):
 
 class AuthorityRecordTC(CubicWebTC):
 
+    configcls = PostgresApptestConfiguration
+
     def test_fti(self):
         with self.admin_access.repo_cnx() as cnx:
             agent = testutils.authority_record(cnx, u'Guenievre', kind=u'person',
@@ -245,6 +254,8 @@ class AuthorityRecordTC(CubicWebTC):
 
 class ConceptSchemeTC(CubicWebTC):
 
+    configcls = PostgresApptestConfiguration
+
     def test_graph_structure(self):
         graph = ConceptSchemeGraph(self.schema)
         expected = {
