@@ -75,13 +75,19 @@ class SKOSImportTC(CubicWebTC):
             dfsource.pull_data(cnx, force=True, raise_on_error=True)
         with self.admin_access.client_cnx() as cnx:
             scheme = cnx.find('ConceptScheme').one()
-            self.assertTrue(scheme.ark.startswith('0/v'))
-            self.assertEqual(len(scheme.top_concepts), 2)
-            self.assertTrue(scheme.top_concepts[0].ark.startswith('0/c'))
+            scheme_ark = scheme.ark
+            self.assertTrue(scheme_ark.startswith('0/rf'))
+            concepts = list(scheme.top_concepts)
+            self.assertEqual(len(concepts), 2)
+            concept_arks = [c.ark for c in concepts]
+            self.assertTrue(all(ark.startswith(scheme_ark + '/') for ark in concept_arks),
+                            concept_arks)
 
 
 class LCSVImportTC(CubicWebTC):
 
+    configcls = PostgresApptestConfiguration
+
     def test_cwuri_with_ark(self):
         with self.admin_access.repo_cnx() as cnx:
             scheme = cnx.create_entity('ConceptScheme', ark_naa=testutils.naa(cnx))
@@ -91,8 +97,8 @@ class LCSVImportTC(CubicWebTC):
                              delimiter='\t', encoding='utf-8', language_code='es')
             concept1 = cnx.find(
                 'Concept', definition="Définition de l'organisation politique de l'organisme").one()
-            self.assertEqual(concept1.cwuri,
-                             'ark:/0/c%09d' % concept1.eid)
+            self.assertTrue(testutils.match_ark_uri(concept1.cwuri),
+                            concept1.cwuri)
 
 
 if __name__ == '__main__':
